"""

    """

import json
from dataclasses import dataclass
from pathlib import Path


class Conf :
    def_fn = Path.cwd().parent / 'conf.json'
    repo_url = 'repo_url'
    python_version = 'python_version'
    module_2_run = "module_2_run"
    rm_venv = 'rm_venv'

@dataclass
class UserRepo :
    user_name: str
    repo_name: str
    user_slash_repo: str
    user_und_repo: str

def get_user_repo_from_url(repo_url) :
    gu = repo_url.split('github.com/')[1]
    user_name = gu.split('/')[0]
    repo_name = gu.split('/')[1]
    user_slash_repo = f'{user_name}/{repo_name}'
    user_und_repo = f'{user_name}_{repo_name}'
    return UserRepo(user_name , repo_name , user_slash_repo , user_und_repo)

def read_json(fp) :
    with open(fp , 'r') as f :
        return json.load(f)



"""

    """

import subprocess

from .github_release import download_latest_release
from .util import Conf
from .util import get_user_repo_from_url
from .util import read_json


cnf = Conf()

def make_venv(fp = cnf.def_fn) :
    js = read_json(fp)

    rp_url = js[cnf.repo_url]
    usrp = get_user_repo_from_url(rp_url)

    pyv = js[cnf.python_version]

    subprocess.run(['pyenv' , 'install' , '--skip-existing' , pyv])
    subprocess.run(['pyenv' , 'virtualenv-delete' , '-f' , usrp.user_und_repo])
    subprocess.run(['pyenv' , 'virtualenv' , pyv , usrp.user_und_repo])

    print(usrp.user_und_repo)

def ret_dirp(fp = cnf.def_fn) :
    js = read_json(fp)
    rp_url = js[cnf.repo_url]
    dirp = download_latest_release(rp_url)
    print(dirp)

def ret_module_2_run_name(fp = cnf.def_fn) :
    js = read_json(fp)
    print(js[cnf.module_2_run])

def rm_venv(fp = cnf.def_fn) :
    js = read_json(fp)

    rp_url = js[cnf.repo_url]
    usrp = get_user_repo_from_url(rp_url)

    rmv = js[cnf.rm_venv]
    if rmv :
        cmd = ['pyenv' , 'virtualenv-delete' , '-f' , usrp.user_und_repo]
        subprocess.run(cmd)
        print(f'\n LOG: {usrp.user_und_repo} venv has been deleted')
    else :
        print(f'\n LOG: {usrp.user_und_repo} venv has NOT been deleted')

def dl_main_bash() :
    rp_url = 'https://github.com/imahdimir/auto-run-bash'
    dirp = download_latest_release(rp_url)
    print(dirp)
